/**
  ******************************************************************************
  * @file    7953_drivers.c
  * @author  Lukas Michalik
  * @version V1.0.0
  * @date    17.5.2012
  * @brief   Input_capture
  ******************************************************************************
  * @attention
  *
  *
  * <h2><center>&copy; COPYRIGHT </center></h2>
  ******************************************************************************
  */


#include "stm32f4xx.h"
#include "7953_driver.h"
#include "SPI_7953.h"
#include "DELAY.h"



/** @defgroup STM32F4_DISCOVERY_LIS302DL_Private_Defines
  * @{
  */
__IO uint32_t  Timeout_7953 = LIS302DL_FLAG_TIMEOUT;

/* Read/Write command */
#define READWRITE_CMD              ((uint16_t)0x8000)
/* Multiple byte read/write command */
#define MULTIPLEBYTE_CMD           ((uint16_t)0x4000)
/* Dummy Byte Send by the SPI Master device in order to generate the Clock to the Slave device */
#define DUMMY_BYTE                 ((uint16_t)0x0000)

void set_7953(void)
{
//write configuration register
//zde doplnit konfiguraci obvodu ADE7953
}

/**
  * @brief  Writes one byte to the LIS302DL.
  * @param  pBuffer : pointer to the buffer  containing the data to be written to the LIS302DL.
  * @param  WriteAddr : LIS302DL's internal address to write to.
  * @param  NumByteToWrite: Number of bytes to write.
  * @retval None
  */


void Write_7953(uint16_t* pBuffer, uint16_t WriteAddr, uint16_t NumByteToWrite)
{
  /* Configure the MS bit:
       - When 0, the address will remain unchanged in multiple read/write commands.
       - When 1, the address will be auto incremented in multiple read/write commands.
  */
  if(NumByteToWrite > 0x01)
  {
    WriteAddr |= (uint16_t)MULTIPLEBYTE_CMD;
  }
  /* Set chip select Low at the start of the transmission */
  ADE7953_CS_LOW();

  /* Send the Address of the indexed register */
  SendByte_7953(WriteAddr);
  /* Send the data that will be written into the device (MSB First) */
  while(NumByteToWrite >= 0x01)
  {
    SendByte_7953(*pBuffer);
    NumByteToWrite--;
    pBuffer++;
  }

  /* Set chip select High at the end of the transmission */
  ADE7953_CS_HIGH();
}


/**
  * @brief  Sends a Byte through the SPI interface and return the Byte received
  *         from the SPI bus.
  * @param  Byte : Byte send.
  * @retval The received byte value
  */
uint16_t SendByte_7953(uint16_t byte)
{
  /* Loop while DR register in not emplty */
  Timeout_7953 = LIS302DL_FLAG_TIMEOUT;
  while (SPI_I2S_GetFlagStatus(ADE7953_SPI, SPI_I2S_FLAG_TXE) == RESET)
  {
    if((Timeout_7953--) == 0) return TIMEOUT_UserCallback_7953();
  }

  /* Send a Byte through the SPI peripheral */
  SPI_I2S_SendData(ADE7953_SPI, byte);

  /* Wait to receive a Byte */
  Timeout_7953 = LIS302DL_FLAG_TIMEOUT;
  while (SPI_I2S_GetFlagStatus(ADE7953_SPI, SPI_I2S_FLAG_RXNE) == RESET)
  {
    if((Timeout_7953--) == 0) return TIMEOUT_UserCallback_7953();
  }

  /* Return the Byte read from the SPI bus */
  return (uint16_t)SPI_I2S_ReceiveData(ADE7953_SPI);
}

/**
  * @brief  MEMS accelerometre management of the timeout situation.
  * @param  None.
  * @retval None.
  */
uint32_t TIMEOUT_UserCallback_7953(void)
{
  /* MEMS Accelerometer Timeout error occured */
  while (1)
  {
  }
  return (0);
}







/**
  * @brief  Reads a block of data from the LIS302DL.
  * @param  pBuffer : pointer to the buffer that receives the data read from the LIS302DL.
  * @param  ReadAddr : LIS302DL's internal address to read from.
  * @param  NumByteToRead : number of bytes to read from the LIS302DL.
  * @retval None
  */
void Read_7953(uint16_t* pBuffer, uint16_t ReadAddr, uint16_t NumByteToRead)
{
  if(NumByteToRead > 0x01)
  {
    ReadAddr |= (uint16_t)(READWRITE_CMD | MULTIPLEBYTE_CMD);
  }
  else
  {
    ReadAddr |= (uint16_t)READWRITE_CMD;
  }
  /* Set chip select Low at the start of the transmission */
  ADE7953_CS_LOW();

  /* Send the Address of the indexed register */
  SendByte_7953(ReadAddr);

  /* Receive the data that will be read from the device (MSB First) */
  while(NumByteToRead > 0x00)
  {
    /* Send dummy byte (0x00) to generate the SPI clock to LIS302DL (Slave device) */
    *pBuffer = SendByte_7953(DUMMY_BYTE);
    NumByteToRead--;
    pBuffer++;
  }

  /* Set chip select High at the end of the transmission */
  ADE7953_CS_HIGH();
}

